
Installation
-------------


    ```pip install -U AutoReg```

Example
---------



from AutoReg import AutoReg

ar=AutoReg()

print(ar.getRegex('ahjas'))


Params
---------


Below are few parameters we have to provide according to our requirements:


1 Case_Sensitive :(default=True)


It is `True` means we consider the case of alphabets else it means we do not consider the lowercase or uppercase of alphabets. 


2 Char_Sensitive :(default=True) 


It is `True` means we consider the count of alphabets present in the string else it will provide the generic one.


3 Digit_Sensitive :(default=True) 


It is `True` means we consider the count of digits present in the string else it will provide the generic one.


4 Space_Sensitive :(default= True)


It is `True` means we consider the count of space present in the string else it will provide the generic one.


5 Specialchar_Sensitive :(default= True) 


It is `True` means we consider the count of special characters present in the string else it will provide the generic one.


`More Updates Coming Soon...` 😄


Contact
---------

I would like to get feedback from the community. If you have feature suggestions, support questions or general comments, please email me at susmit.vssut@gmail.com

